@@ -91,3 +91,46 @@ double expected_MI(IntegerVector ni_, IntegerVector n_j) {
   return emi;
 
 }
+
+// [[Rcpp::export]]
+List getRank(IntegerVector classi){
+   int maxi = max(classi);
+   int mini = min(classi);
+
+   // Present
+   LogicalVector present(maxi - mini + 1);
+   for(int i=0; i< classi.size(); i++) present[classi[i]-mini] = TRUE;
+   
+   // Count
+   IntegerVector translator(maxi - mini + 1);
+   int nbIndex = 0;
+   for(int i=0; i< present.size(); i++) {
+     if(present[i]) nbIndex++;
+   }
+
+   // Translator and Index Vector
+   IntegerVector index(nbIndex);
+   int indexCur = 0;
+   for(int i=0; i< present.size(); i++) {
+     if(present[i]) { 
+        translator[i] = indexCur;
+	index[indexCur] = i+mini;
+	indexCur++;
+     } else {
+        translator[i] = R_NaN;
+     }
+   }
+   // Converted Vector
+   IntegerVector translated(classi.size());
+   for(int i=0; i< classi.size(); i++) translated[i] = translator[classi[i] - mini];
+
+   // output as a list
+   List ListOut;
+   ListOut["index"] =  index;
+   ListOut["translator"] = translator;
+   ListOut["translated"]   = translated;
+   return ListOut;
+} 
+  
+
+   
